@@ -2,12 +2,16 @@ import copy
 import itertools
 import json
 from functools import wraps
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Optional, Union
 
 from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
 from moto.dynamodb.comparisons import create_condition_expression_parser
 from moto.dynamodb.models import DynamoDBBackend, Table, dynamodb_backends
+from moto.dynamodb.models.table import (
+    DEFAULT_WARM_THROUGHPUT_RCU,
+    DEFAULT_WARM_THROUGHPUT_WCU,
+)
 from moto.dynamodb.models.utilities import dynamo_json_dump
 from moto.dynamodb.parsing.expressions import (  # type: ignore
     ExpressionAttributeName,
@@ -88,7 +92,7 @@ def include_consumed_capacity(
 
 
 def validate_put_has_empty_keys(
-    field_updates: Dict[str, Any], table: Table, custom_error_msg: Optional[str] = None
+    field_updates: dict[str, Any], table: Table, custom_error_msg: Optional[str] = None
 ) -> None:
     """
     Error if any keys have an empty value. Checks Global index attributes as well
@@ -128,9 +132,9 @@ def validate_put_has_empty_keys(
             raise MockValidationException(msg.format(empty_key))
 
 
-def validate_put_has_empty_attrs(field_updates: Dict[str, Any], table: Table) -> None:
+def validate_put_has_empty_attrs(field_updates: dict[str, Any], table: Table) -> None:
     # Example invalid attribute: [{'M': {'SS': {'NS': []}}}]
-    def _validate_attr(attr: Dict[str, Any]) -> None:
+    def _validate_attr(attr: dict[str, Any]) -> None:
         for set_type, error in [("NS", "number"), ("SS", "string")]:
             if set_type in attr and attr[set_type] == []:
                 raise MockValidationException(
@@ -148,7 +152,7 @@ def validate_put_has_empty_attrs(field_updates: Dict[str, Any], table: Table) ->
                 _validate_attr(val)
 
 
-def validate_put_has_gsi_keys_set_to_none(item: Dict[str, Any], table: Table) -> None:
+def validate_put_has_gsi_keys_set_to_none(item: dict[str, Any], table: Table) -> None:
     for gsi in table.global_indexes:
         for attr in gsi.schema:
             attr_name = attr["AttributeName"]
@@ -159,8 +163,8 @@ def validate_put_has_gsi_keys_set_to_none(item: Dict[str, Any], table: Table) ->
 
 
 def validate_attributes_used(
-    attribute_names: Optional[Dict[str, Any]],
-    names_used: List[str],
+    attribute_names: Optional[dict[str, Any]],
+    names_used: list[str],
     provided_attr: str = "Names",
 ) -> None:
     for name in attribute_names or []:
@@ -189,16 +193,16 @@ class ProjectionExpressionParser:
     def __init__(
         self,
         projection_expression: Optional[str],
-        expression_attribute_names: Optional[Dict[str, str]],
+        expression_attribute_names: Optional[dict[str, str]],
     ):
         self.projection_expression = projection_expression
         self.expression_attribute_names = (
             expression_attribute_names if expression_attribute_names else {}
         )
 
-        self.expr_attr_names_found: List[str] = []
+        self.expr_attr_names_found: list[str] = []
 
-    def parse(self) -> List[List[str]]:
+    def parse(self) -> list[list[str]]:
         """
         lvl1.lvl2.attr1,lvl1.attr2 --> [["lvl1", "lvl2", "attr1"], ["lvl1", "attr2]]
         """
@@ -261,7 +265,7 @@ class DynamoHandler(BaseResponse):
             limit, exclusive_start_table_name
         )
 
-        response: Dict[str, Any] = {"TableNames": tables}
+        response: dict[str, Any] = {"TableNames": tables}
         if last_eval:
             response["LastEvaluatedTableName"] = last_eval
 
@@ -284,6 +288,7 @@ class DynamoHandler(BaseResponse):
         streams = body.get("StreamSpecification")
         tags = body.get("Tags", [])
         deletion_protection_enabled = body.get("DeletionProtectionEnabled", False)
+        warm_throughput = body.get("WarmThroughput")
 
         self._validate_table_creation(
             billing_mode=billing_mode,
@@ -292,6 +297,7 @@ class DynamoHandler(BaseResponse):
             global_indexes=global_indexes,
             local_secondary_indexes=local_secondary_indexes,
             attr=attr,
+            warm_throughput=warm_throughput,
         )
 
         table = self.dynamodb_backend.create_table(
@@ -306,17 +312,19 @@ class DynamoHandler(BaseResponse):
             sse_specification=sse_spec,
             tags=tags,
             deletion_protection_enabled=deletion_protection_enabled,
+            warm_throughput=warm_throughput,
         )
         return dynamo_json_dump(table.describe())
 
     def _validate_table_creation(
         self,
         billing_mode: str,
-        throughput: Optional[Dict[str, Any]],
-        key_schema: List[Dict[str, str]],
-        global_indexes: Optional[List[Dict[str, Any]]],
-        local_secondary_indexes: Optional[List[Dict[str, Any]]],
-        attr: List[Dict[str, str]],
+        throughput: Optional[dict[str, Any]],
+        key_schema: list[dict[str, str]],
+        global_indexes: Optional[list[dict[str, Any]]],
+        local_secondary_indexes: Optional[list[dict[str, Any]]],
+        attr: list[dict[str, str]],
+        warm_throughput: Optional[dict[str, Any]],
     ) -> None:
         # Validate Throughput
         if billing_mode == "PAY_PER_REQUEST" and throughput:
@@ -350,6 +358,40 @@ class DynamoHandler(BaseResponse):
                 "One or more parameter values were invalid: List of GlobalSecondaryIndexes is empty"
             )
         for idx, g_idx in enumerate(global_indexes or [], start=1):
+            idx_throughput = g_idx.get("ProvisionedThroughput", None)
+            idx_warm_throughput = g_idx.get("WarmThroughput", None)
+            min_rcu = (
+                idx_throughput["ReadCapacityUnits"]
+                if idx_throughput
+                else DEFAULT_WARM_THROUGHPUT_RCU
+            )
+            min_wcu = (
+                idx_throughput["WriteCapacityUnits"]
+                if idx_throughput
+                else DEFAULT_WARM_THROUGHPUT_WCU
+            )
+
+            if idx_throughput:
+                error_rcu_end = "ReadCapacityUnits of ProvisionedThroughput"
+                error_wcu_end = "WriteCapacityUnits of ProvisionedThroughput"
+            else:
+                error_rcu_end = "initial throughput for OnDemand"
+                error_wcu_end = "initial throughput for OnDemand"
+
+            error_rcu = f"One or more parameter values were invalid: Requested ReadUnitsPerSecond for WarmThroughput for index {g_idx['IndexName']} is lower than {error_rcu_end}"
+            error_wcu = f"One or more parameter values were invalid: Requested WriteUnitsPerSecond for WarmThroughput for index {g_idx['IndexName']} is lower than {error_wcu_end}"
+
+            if (
+                idx_warm_throughput
+                and idx_warm_throughput.get("ReadUnitsPerSecond", min_rcu) < min_rcu
+            ):
+                raise MockValidationException(error_rcu)
+            if (
+                idx_warm_throughput
+                and idx_warm_throughput.get("WriteUnitsPerSecond", min_wcu) < min_wcu
+            ):
+                raise MockValidationException(error_wcu)
+
             for idx2, _key in enumerate(g_idx["KeySchema"], start=1):
                 key_type = _key["KeyType"]
                 if key_type not in ["HASH", "RANGE"]:
@@ -372,12 +414,12 @@ class DynamoHandler(BaseResponse):
         expected_attrs = []
         expected_attrs.extend([key["AttributeName"] for key in key_schema])
         local_key_schemas = itertools.chain(
-            *list(idx["KeySchema"] for idx in (local_secondary_indexes or []))
+            *[idx["KeySchema"] for idx in (local_secondary_indexes or [])]
         )
         expected_attrs.extend(schema["AttributeName"] for schema in local_key_schemas)
 
         global_key_schemas = itertools.chain(
-            *list(idx["KeySchema"] for idx in (global_indexes or []))
+            *[idx["KeySchema"] for idx in (global_indexes or [])]
         )
         expected_attrs.extend(schema["AttributeName"] for schema in global_key_schemas)
         expected_attrs = list(set(expected_attrs))
@@ -388,10 +430,43 @@ class DynamoHandler(BaseResponse):
         if actual_attrs != expected_attrs:
             self._throw_attr_error(actual_attrs, expected_attrs, has_index)
 
+        # Validate WarmThroughput
+        min_rcu = (
+            throughput["ReadCapacityUnits"]
+            if throughput
+            else DEFAULT_WARM_THROUGHPUT_RCU
+        )
+        min_wcu = (
+            throughput["WriteCapacityUnits"]
+            if throughput
+            else DEFAULT_WARM_THROUGHPUT_WCU
+        )
+
+        if throughput:
+            error_rcu_end = "ReadCapacityUnits of ProvisionedThroughput"
+            error_wcu_end = "WriteCapacityUnits of ProvisionedThroughput"
+        else:
+            error_rcu_end = "initial throughput for OnDemand"
+            error_wcu_end = "initial throughput for OnDemand"
+
+        error_rcu = f"One or more parameter values were invalid: Requested ReadUnitsPerSecond for WarmThroughput for table is lower than {error_rcu_end}"
+        error_wcu = f"One or more parameter values were invalid: Requested WriteUnitsPerSecond for WarmThroughput for table is lower than {error_wcu_end}"
+
+        if (
+            warm_throughput
+            and warm_throughput.get("ReadUnitsPerSecond", min_rcu) < min_rcu
+        ):
+            raise MockValidationException(error_rcu)
+        if (
+            warm_throughput
+            and warm_throughput.get("WriteUnitsPerSecond", min_wcu) < min_wcu
+        ):
+            raise MockValidationException(error_wcu)
+
     def _throw_attr_error(
-        self, actual_attrs: List[str], expected_attrs: List[str], indexes: bool
+        self, actual_attrs: list[str], expected_attrs: list[str], indexes: bool
     ) -> None:
-        def dump_list(list_: List[str]) -> str:
+        def dump_list(list_: list[str]) -> str:
             return str(list_).replace("'", "")
 
         err_head = "One or more parameter values were invalid: "
@@ -503,6 +578,7 @@ class DynamoHandler(BaseResponse):
         billing_mode = self.body.get("BillingMode", None)
         stream_spec = self.body.get("StreamSpecification", None)
         deletion_protection_enabled = self.body.get("DeletionProtectionEnabled")
+        warm_throughput = self.body.get("WarmThroughput")
         table = self.dynamodb_backend.update_table(
             name=name,
             attr_definitions=attr_definitions,
@@ -511,6 +587,7 @@ class DynamoHandler(BaseResponse):
             billing_mode=billing_mode,
             stream_spec=stream_spec,
             deletion_protection_enabled=deletion_protection_enabled,
+            warm_throughput=warm_throughput,
         )
         return dynamo_json_dump(table.describe())
 
@@ -659,7 +736,7 @@ class DynamoHandler(BaseResponse):
                     "ExpressionAttributeNames must not be empty"
                 )
 
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
         expression_attribute_names = expression_attribute_names or {}
@@ -683,7 +760,7 @@ class DynamoHandler(BaseResponse):
     def batch_get_item(self) -> str:
         table_batches = self.body["RequestItems"]
 
-        results: Dict[str, Any] = {
+        results: dict[str, Any] = {
             "ConsumedCapacity": [],
             "Responses": {},
             "UnprocessedKeys": {},
@@ -750,7 +827,7 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(results)
 
-    def _contains_duplicates(self, keys: List[str]) -> bool:
+    def _contains_duplicates(self, keys: list[str]) -> bool:
         unique_keys = []
         for k in keys:
             if k in unique_keys:
@@ -867,7 +944,7 @@ class DynamoHandler(BaseResponse):
             **filter_kwargs,
         )
 
-        result: Dict[str, Any] = {
+        result: dict[str, Any] = {
             "Count": len(items),
             "ScannedCount": scanned_count,
         }
@@ -977,7 +1054,7 @@ class DynamoHandler(BaseResponse):
             raise MockValidationException("Return values set to invalid value")
 
         table = self.dynamodb_backend.get_table(name)
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
         # Attempt to parse simple ConditionExpressions into an Expected
@@ -1027,7 +1104,7 @@ class DynamoHandler(BaseResponse):
             )
 
         table = self.dynamodb_backend.get_table(name)
-        if not all([k in table.attribute_keys for k in key]):
+        if not all(k in table.attribute_keys for k in key):
             raise ProvidedKeyDoesNotExist
 
         expression_attribute_names_used = []
@@ -1138,7 +1215,7 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(item_dict)
 
-    def _get_expr_attr_values(self) -> Dict[str, Dict[str, str]]:
+    def _get_expr_attr_values(self) -> dict[str, dict[str, str]]:
         values = self.body.get("ExpressionAttributeValues")
         if values is None:
             return {}
@@ -1206,30 +1283,28 @@ class DynamoHandler(BaseResponse):
 
     def transact_get_items(self) -> str:
         transact_items = self.body["TransactItems"]
-        responses: List[Dict[str, Any]] = list()
+        responses: list[dict[str, Any]] = []
 
         if len(transact_items) > TRANSACTION_MAX_ITEMS:
             msg = "1 validation error detected: Value '["
-            err_list = list()
+            err_list = []
             request_id = 268435456
             for _ in transact_items:
                 request_id += 1
                 hex_request_id = format(request_id, "x")
                 err_list.append(
-                    "com.amazonaws.dynamodb.v20120810.TransactGetItem@%s"
-                    % hex_request_id
+                    f"com.amazonaws.dynamodb.v20120810.TransactGetItem@{hex_request_id}"
                 )
             msg += ", ".join(err_list)
             msg += (
                 "'] at 'transactItems' failed to satisfy constraint: "
-                "Member must have length less than or equal to %s"
-                % TRANSACTION_MAX_ITEMS
+                f"Member must have length less than or equal to {TRANSACTION_MAX_ITEMS}"
             )
 
             raise MockValidationException(msg)
 
         ret_consumed_capacity = self.body.get("ReturnConsumedCapacity", "NONE")
-        consumed_capacity: Dict[str, Any] = dict()
+        consumed_capacity: dict[str, Any] = {}
 
         for transact_item in transact_items:
             table_name = transact_item["Get"]["TableName"]
@@ -1257,10 +1332,10 @@ class DynamoHandler(BaseResponse):
                     "ReadCapacityUnits": read_capacity_units,
                 }
 
-        result = dict()
+        result = {}
         result.update({"Responses": responses})
         if ret_consumed_capacity != "NONE":
-            result.update({"ConsumedCapacity": [v for v in consumed_capacity.values()]})
+            result.update({"ConsumedCapacity": list(consumed_capacity.values())})
 
         return dynamo_json_dump(result)
 
@@ -1320,7 +1395,7 @@ class DynamoHandler(BaseResponse):
             )
 
         self.dynamodb_backend.transact_write_items(transact_items)
-        response: Dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
+        response: dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
         return dynamo_json_dump(response)
 
     def describe_continuous_backups(self) -> str:
@@ -1425,6 +1500,7 @@ class DynamoHandler(BaseResponse):
             global_indexes=global_indexes,
             local_secondary_indexes=None,
             attr=table_attrs,
+            warm_throughput=None,
         )
 
         import_table = self.dynamodb_backend.import_table(
