@@ -32,7 +32,7 @@ class LaunchTemplateVersion:
         self.data = data
         self.description = description
         self.create_time = utc_date_and_time()
-        self.instance_tags = convert_tag_spec(data.get("TagSpecification", [])).get(
+        self.instance_tags = convert_tag_spec(data.get("TagSpecifications", [])).get(
             "instance", {}
         )
 
