@@ -1,67 +1,83 @@
-from __future__ import unicode_literals
-from jinja2 import Template
-
-from moto.core.responses import BaseResponse
-from moto.ec2.utils import filters_from_querystring
+from ._base_response import EC2BaseResponse
 
 
-class SpotInstances(BaseResponse):
-    def _get_param(self, param_name):
-        return self.querystring.get(param_name, [None])[0]
+class SpotInstances(EC2BaseResponse):
+    def cancel_spot_instance_requests(self) -> str:
+        request_ids = self._get_param("SpotInstanceRequestIds", [])
 
-    def _get_int_param(self, param_name):
-        value = self._get_param(param_name)
-        if value is not None:
-            return int(value)
+        self.error_on_dryrun()
 
-    def cancel_spot_instance_requests(self):
-        request_ids = self._get_multi_param('SpotInstanceRequestId')
         requests = self.ec2_backend.cancel_spot_instance_requests(request_ids)
-        template = Template(CANCEL_SPOT_INSTANCES_TEMPLATE)
+        template = self.response_template(CANCEL_SPOT_INSTANCES_TEMPLATE)
         return template.render(requests=requests)
 
-    def create_spot_datafeed_subscription(self):
-        raise NotImplementedError('SpotInstances.create_spot_datafeed_subscription is not yet implemented')
+    def create_spot_datafeed_subscription(self) -> None:
+        self.error_on_dryrun()
 
-    def delete_spot_datafeed_subscription(self):
-        raise NotImplementedError('SpotInstances.delete_spot_datafeed_subscription is not yet implemented')
+        raise NotImplementedError(
+            "SpotInstances.create_spot_datafeed_subscription is not yet implemented"
+        )
 
-    def describe_spot_datafeed_subscription(self):
-        raise NotImplementedError('SpotInstances.describe_spot_datafeed_subscription is not yet implemented')
+    def delete_spot_datafeed_subscription(self) -> None:
+        self.error_on_dryrun()
 
-    def describe_spot_instance_requests(self):
-        filters = filters_from_querystring(self.querystring)
-        requests = self.ec2_backend.describe_spot_instance_requests(filters=filters)
-        template = Template(DESCRIBE_SPOT_INSTANCES_TEMPLATE)
+        raise NotImplementedError(
+            "SpotInstances.delete_spot_datafeed_subscription is not yet implemented"
+        )
+
+    def describe_spot_datafeed_subscription(self) -> None:
+        raise NotImplementedError(
+            "SpotInstances.describe_spot_datafeed_subscription is not yet implemented"
+        )
+
+    def describe_spot_instance_requests(self) -> str:
+        spot_instance_ids = self._get_param("SpotInstanceRequestIds", [])
+        filters = self._filters_from_querystring()
+        requests = self.ec2_backend.describe_spot_instance_requests(
+            filters=filters, spot_instance_ids=spot_instance_ids
+        )
+        template = self.response_template(DESCRIBE_SPOT_INSTANCES_TEMPLATE)
         return template.render(requests=requests)
 
-    def describe_spot_price_history(self):
-        raise NotImplementedError('SpotInstances.describe_spot_price_history is not yet implemented')
+    def describe_spot_price_history(self) -> str:
+        instance_types_filters = self._get_param("InstanceTypes", [])
+        filter_dict = self._filters_from_querystring()
+        prices = self.ec2_backend.describe_spot_price_history(
+            instance_types_filters, filter_dict
+        )
+        template = self.response_template(DESCRIBE_SPOT_PRICE_HISTORY_TEMPLATE)
+        return template.render(prices=prices)
 
-    def request_spot_instances(self):
-        price = self._get_param('SpotPrice')
-        image_id = self._get_param('LaunchSpecification.ImageId')
-        count = self._get_int_param('InstanceCount')
-        type = self._get_param('Type')
-        valid_from = self._get_param('ValidFrom')
-        valid_until = self._get_param('ValidUntil')
-        launch_group = self._get_param('LaunchGroup')
-        availability_zone_group = self._get_param('AvailabilityZoneGroup')
-        key_name = self._get_param('LaunchSpecification.KeyName')
-        security_groups = self._get_multi_param('LaunchSpecification.SecurityGroup')
-        user_data = self._get_param('LaunchSpecification.UserData')
-        instance_type = self._get_param('LaunchSpecification.InstanceType')
-        placement = self._get_param('LaunchSpecification.Placement.AvailabilityZone')
-        kernel_id = self._get_param('LaunchSpecification.KernelId')
-        ramdisk_id = self._get_param('LaunchSpecification.RamdiskId')
-        monitoring_enabled = self._get_param('LaunchSpecification.Monitoring.Enabled')
-        subnet_id = self._get_param('LaunchSpecification.SubnetId')
+    def request_spot_instances(self) -> str:
+        price = self._get_param("SpotPrice")
+        image_id = self._get_param("LaunchSpecification.ImageId")
+        count = self._get_int_param("InstanceCount", 1)
+        spot_instance_type = self._get_param("Type", "one-time")
+        valid_from = self._get_param("ValidFrom")
+        valid_until = self._get_param("ValidUntil")
+        launch_group = self._get_param("LaunchGroup")
+        availability_zone_group = self._get_param("AvailabilityZoneGroup")
+        key_name = self._get_param("LaunchSpecification.KeyName")
+        security_groups = self._get_param("LaunchSpecification.SecurityGroups", [])
+        user_data = self._get_param("LaunchSpecification.UserData")
+        instance_type = self._get_param("LaunchSpecification.InstanceType", "m1.small")
+        placement = self._get_param("LaunchSpecification.Placement.AvailabilityZone")
+        kernel_id = self._get_param("LaunchSpecification.KernelId")
+        ramdisk_id = self._get_param("LaunchSpecification.RamdiskId")
+        monitoring_enabled = self._get_param("LaunchSpecification.Monitoring.Enabled")
+        subnet_id = self._get_param("LaunchSpecification.SubnetId")
+        instance_interruption_behaviour = self._get_param(
+            "InstanceInterruptionBehavior"
+        )
+        tags = self._parse_tag_specification()
+
+        self.error_on_dryrun()
 
         requests = self.ec2_backend.request_spot_instances(
             price=price,
             image_id=image_id,
             count=count,
-            type=type,
+            spot_instance_type=spot_instance_type,
             valid_from=valid_from,
             valid_until=valid_until,
             launch_group=launch_group,
@@ -75,13 +91,15 @@ class SpotInstances(BaseResponse):
             ramdisk_id=ramdisk_id,
             monitoring_enabled=monitoring_enabled,
             subnet_id=subnet_id,
+            instance_interruption_behaviour=instance_interruption_behaviour,
+            tags=tags,
         )
 
-        template = Template(REQUEST_SPOT_INSTANCES_TEMPLATE)
+        template = self.response_template(REQUEST_SPOT_INSTANCES_TEMPLATE)
         return template.render(requests=requests)
 
 
-REQUEST_SPOT_INSTANCES_TEMPLATE = """<RequestSpotInstancesResponse xmlns="http://ec2.amazonaws.com/doc/2013-06-15/">
+REQUEST_SPOT_INSTANCES_TEMPLATE = """<RequestSpotInstancesResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
   <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
   <spotInstanceRequestSet>
     {% for request in requests %}
@@ -91,9 +109,9 @@ REQUEST_SPOT_INSTANCES_TEMPLATE = """<RequestSpotInstancesResponse xmlns="http:/
       <type>{{ request.type }}</type>
       <state>{{ request.state }}</state>
       <status>
-        <code>pending-evaluation</code>
-        <updateTime>YYYY-MM-DDTHH:MM:SS.000Z</updateTime>
-        <message>Your Spot request has been submitted for review, and is pending evaluation.</message>
+        <code>{{ request.status }}</code>
+        <updateTime>2015-01-01T00:00:00.000Z</updateTime>
+        <message>{{ request.status_message }}</message>
       </status>
       <instanceId>{{ request.instance_id }}</instanceId>
       <availabilityZoneGroup>{{ request.availability_zone_group }}</availabilityZoneGroup>
@@ -123,12 +141,12 @@ REQUEST_SPOT_INSTANCES_TEMPLATE = """<RequestSpotInstancesResponse xmlns="http:/
         </PlacementRequestType>
       </launchSpecification>
       <launchGroup>{{ request.launch_group }}</launchGroup>
-      <createTime>YYYY-MM-DDTHH:MM:SS.000Z</createTime>
+      <createTime>2015-01-01T00:00:00.000Z</createTime>
       {% if request.valid_from %}
-      <validFrom>{{ request.valid_from }}</validFrom>
+      <validFrom>{{ request.valid_from_as_string }}</validFrom>
       {% endif %}
       {% if request.valid_until %}
-      <validUntil>{{ request.valid_until }}</validUntil>
+      <validUntil>{{ request.valid_until_as_string }}</validUntil>
       {% endif %}
       <productDescription>Linux/UNIX</productDescription>
     </item>
@@ -136,7 +154,7 @@ REQUEST_SPOT_INSTANCES_TEMPLATE = """<RequestSpotInstancesResponse xmlns="http:/
  </spotInstanceRequestSet>
 </RequestSpotInstancesResponse>"""
 
-DESCRIBE_SPOT_INSTANCES_TEMPLATE = """<DescribeSpotInstanceRequestsResponse xmlns="http://ec2.amazonaws.com/doc/2013-06-15/">
+DESCRIBE_SPOT_INSTANCES_TEMPLATE = """<DescribeSpotInstanceRequestsResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
   <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
   <spotInstanceRequestSet>
     {% for request in requests %}
@@ -146,11 +164,11 @@ DESCRIBE_SPOT_INSTANCES_TEMPLATE = """<DescribeSpotInstanceRequestsResponse xmln
       <type>{{ request.type }}</type>
       <state>{{ request.state }}</state>
       <status>
-        <code>pending-evaluation</code>
-        <updateTime>YYYY-MM-DDTHH:MM:SS.000Z</updateTime>
-        <message>Your Spot request has been submitted for review, and is pending evaluation.</message>
+        <code>{{ request.status }}</code>
+        <updateTime>2015-01-01T00:00:00.000Z</updateTime>
+        <message>{{ request.status_message }}</message>
       </status>
-      <instanceId>{{ request.instance_id }}</instanceId>
+      <instanceId>{{ request.instance.id }}</instanceId>
       {% if request.availability_zone_group %}
         <availabilityZoneGroup>{{ request.availability_zone_group }}</availabilityZoneGroup>
       {% endif %}
@@ -202,20 +220,21 @@ DESCRIBE_SPOT_INSTANCES_TEMPLATE = """<DescribeSpotInstanceRequestsResponse xmln
       {% if request.launch_group %}
         <launchGroup>{{ request.launch_group }}</launchGroup>
       {% endif %}
-        <createTime>YYYY-MM-DDTHH:MM:SS.000Z</createTime>
+        <createTime>2015-01-01T00:00:00.000Z</createTime>
       {% if request.valid_from %}
-        <validFrom>{{ request.valid_from }}</validFrom>
+        <validFrom>{{ request.valid_from_as_string }}</validFrom>
       {% endif %}
       {% if request.valid_until %}
-        <validUntil>{{ request.valid_until }}</validUntil>
+        <validUntil>{{ request.valid_until_as_string }}</validUntil>
       {% endif %}
       <productDescription>Linux/UNIX</productDescription>
+      <instanceInterruptionBehavior>{{ request.instance_interruption_behaviour }}</instanceInterruptionBehavior>
     </item>
     {% endfor %}
   </spotInstanceRequestSet>
 </DescribeSpotInstanceRequestsResponse>"""
 
-CANCEL_SPOT_INSTANCES_TEMPLATE = """<CancelSpotInstanceRequestsResponse xmlns="http://ec2.amazonaws.com/doc/2013-06-15/">
+CANCEL_SPOT_INSTANCES_TEMPLATE = """<CancelSpotInstanceRequestsResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
   <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
   <spotInstanceRequestSet>
     {% for request in requests %}
@@ -226,3 +245,18 @@ CANCEL_SPOT_INSTANCES_TEMPLATE = """<CancelSpotInstanceRequestsResponse xmlns="h
     {% endfor %}
   </spotInstanceRequestSet>
 </CancelSpotInstanceRequestsResponse>"""
+
+DESCRIBE_SPOT_PRICE_HISTORY_TEMPLATE = """<DescribeSpotPriceHistoryResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
+  <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
+  <spotPriceHistorySet>
+    {% for price in prices %}
+    <item>
+      <instanceType>{{ price.InstanceType }}</instanceType>
+      <productDescription>Linux/UNIX (Amazon VPC)</productDescription>
+      <spotPrice>0.00001</spotPrice>
+      <availabilityZone>{{ price.Location }}</availabilityZone>
+      <timestamp>2006-01-02T15:04:05.999999999Z</timestamp>
+    </item>
+    {% endfor %}
+  </spotPriceHistorySet>
+  </DescribeSpotPriceHistoryResponse>"""
