@@ -1,15 +1,17 @@
 """Route53Backend class with methods for supported APIs."""
+
 import copy
 import itertools
 import re
 import string
 from collections import defaultdict
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Optional
 
 from jinja2 import Template
 
-from moto.core import BackendDict, BaseBackend, BaseModel, CloudFormationModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
 from moto.moto_api._internal import mock_random as random
 from moto.route53.exceptions import (
     ConflictingDomainExists,
@@ -29,15 +31,44 @@ from moto.route53.exceptions import (
     ResourceRecordAlreadyExists,
 )
 from moto.utilities.paginator import paginate
+from moto.utilities.utils import PARTITION_NAMES, get_partition
 
-from .utils import PAGINATION_MODEL
+from ..utilities.id_generator import ExistingIds, ResourceIdentifier, Tags, moto_id
+from .utils import PAGINATION_MODEL, validate_domain_name
 
 ROUTE53_ID_CHOICE = string.ascii_uppercase + string.digits
+LOGS_GROUP_REGION = "us-east-1"
+LOGS_GROUP_ARN_REGEX = re.compile(
+    rf"arn:aws:logs:{LOGS_GROUP_REGION}:\d{{12}}:log-group:.+"
+)
 
 
-def create_route53_zone_id() -> str:
+class HostedZoneIdentifier(ResourceIdentifier):
+    service = "route53"
+    resource = "hosted_zone"
+
+    def __init__(self, account_id: str, name: str, delegation_set_id: Optional[str]):
+        # the region is left blank as route53 is a global service
+        super().__init__(
+            account_id=account_id,
+            region="",
+            name=".".join((name, delegation_set_id or "")),
+        )
+
+    def generate(self, existing_ids: ExistingIds = None, tags: Tags = None) -> str:
+        return create_route53_zone_id(
+            resource_identifier=self, existing_ids=existing_ids, tags=tags
+        )
+
+
+@moto_id
+def create_route53_zone_id(  # type: ignore
+    resource_identifier: ResourceIdentifier,
+    existing_ids: ExistingIds = None,
+    tags: Tags = None,
+) -> str:
     # New ID's look like this Z1RWWTK7Y8UDDQ
-    return "".join([random.choice(ROUTE53_ID_CHOICE) for _ in range(0, 15)])
+    return "".join([random.choice(ROUTE53_ID_CHOICE) for _ in range(0, 22)])
 
 
 def create_route53_caller_reference() -> str:
@@ -50,7 +81,7 @@ class DelegationSet(BaseModel):
     def __init__(
         self,
         caller_reference: str,
-        name_servers: Optional[List[str]],
+        name_servers: Optional[list[str]],
         delegation_set_id: Optional[str],
     ):
         self.caller_reference = caller_reference
@@ -71,7 +102,7 @@ class HealthCheck(CloudFormationModel):
         self,
         health_check_id: str,
         caller_reference: str,
-        health_check_args: Dict[str, Any],
+        health_check_args: dict[str, Any],
     ):
         self.id = health_check_id
         self.ip_address = health_check_args.get("ip_address")
@@ -93,13 +124,13 @@ class HealthCheck(CloudFormationModel):
 
     def set_children(self, children: Any) -> None:
         if children and isinstance(children, list):
-            self.children = children  # type: ignore
+            self.children = children
         elif children and isinstance(children, str):
             self.children = [children]  # type: ignore
 
     def set_regions(self, regions: Any) -> None:
         if regions and isinstance(regions, list):
-            self.regions = regions  # type: ignore
+            self.regions = regions
         elif regions and isinstance(regions, str):
             self.regions = [regions]  # type: ignore
 
@@ -136,7 +167,7 @@ class HealthCheck(CloudFormationModel):
             "request_interval": properties.get("RequestInterval"),
             "failure_threshold": properties.get("FailureThreshold"),
         }
-        backend = route53_backends[account_id]["global"]
+        backend = route53_backends[account_id][get_partition(region_name)]
         health_check = backend.create_health_check(
             caller_reference=resource_name, health_check_args=health_check_args
         )
@@ -195,7 +226,7 @@ class HealthCheck(CloudFormationModel):
 
 
 class RecordSet(CloudFormationModel):
-    def __init__(self, kwargs: Dict[str, Any]):
+    def __init__(self, kwargs: dict[str, Any]):
         self.name = kwargs.get("Name", "")
         self.type_ = kwargs.get("Type")
         self.ttl = kwargs.get("TTL", 0)
@@ -232,7 +263,7 @@ class RecordSet(CloudFormationModel):
         properties = cloudformation_json["Properties"]
 
         zone_name = properties.get("HostedZoneName")
-        backend = route53_backends[account_id]["global"]
+        backend = route53_backends[account_id][get_partition(region_name)]
         hosted_zone = backend.get_hosted_zone_by_name(zone_name) if zone_name else None
         if hosted_zone is None:
             hosted_zone = backend.get_hosted_zone(properties["HostedZoneId"])
@@ -268,7 +299,7 @@ class RecordSet(CloudFormationModel):
         properties = cloudformation_json["Properties"]
 
         zone_name = properties.get("HostedZoneName")
-        backend = route53_backends[account_id]["global"]
+        backend = route53_backends[account_id][get_partition(region_name)]
         hosted_zone = backend.get_hosted_zone_by_name(zone_name) if zone_name else None
         if hosted_zone is None:
             hosted_zone = backend.get_hosted_zone(properties["HostedZoneId"])
@@ -282,11 +313,9 @@ class RecordSet(CloudFormationModel):
     def physical_resource_id(self) -> str:
         return self.name
 
-    def delete(
-        self, account_id: str, region: str  # pylint: disable=unused-argument
-    ) -> None:
+    def delete(self, account_id: str, region: str) -> None:
         """Not exposed as part of the Route 53 API - used for CloudFormation"""
-        backend = route53_backends[account_id]["global"]
+        backend = route53_backends[account_id][get_partition(region)]
         hosted_zone = (
             backend.get_hosted_zone_by_name(self.hosted_zone_name)
             if self.hosted_zone_name
@@ -303,7 +332,7 @@ def reverse_domain_name(domain_name: str) -> str:
     return ".".join(reversed(domain_name.split(".")))
 
 
-class ChangeList(List[Dict[str, Any]]):
+class ChangeList(list[dict[str, Any]]):
     """
     Contains a 'clean' list of ResourceRecordChangeSets
     """
@@ -316,7 +345,7 @@ class ChangeList(List[Dict[str, Any]]):
         item["ResourceRecordSet"]["Name"] = item["ResourceRecordSet"]["Name"].strip(".")
         return super().__contains__(item)
 
-    def has_insert_or_update(self, new_rr_set: Dict[str, Any]) -> bool:
+    def has_insert_or_update(self, new_rr_set: dict[str, Any]) -> bool:
         """
         Check if a CREATE or UPSERT record exists where the name and type is the same as the provided record
         If the existing record has TTL/ResourceRecords, the new TTL should have the same
@@ -350,21 +379,21 @@ class FakeZone(CloudFormationModel):
     ):
         self.name = name
         self.id = id_
-        self.vpcs: List[Dict[str, Any]] = []
+        self.vpcs: list[dict[str, Any]] = []
         if comment is not None:
             self.comment = comment
         self.caller_reference = caller_reference
         self.private_zone = private_zone
-        self.rrsets: List[RecordSet] = []
+        self.rrsets: list[RecordSet] = []
         self.delegation_set = delegation_set
         self.rr_changes = ChangeList()
 
-    def add_rrset(self, record_set: Dict[str, Any]) -> RecordSet:
+    def add_rrset(self, record_set: dict[str, Any]) -> RecordSet:
         record_set_obj = RecordSet(record_set)
         self.rrsets.append(record_set_obj)
         return record_set_obj
 
-    def upsert_rrset(self, record_set: Dict[str, Any]) -> RecordSet:
+    def upsert_rrset(self, record_set: dict[str, Any]) -> RecordSet:
         new_rrset = RecordSet(record_set)
         for i, rrset in enumerate(self.rrsets):
             if (
@@ -378,7 +407,7 @@ class FakeZone(CloudFormationModel):
             self.rrsets.append(new_rrset)
         return new_rrset
 
-    def delete_rrset(self, rrset: Dict[str, Any]) -> None:
+    def delete_rrset(self, rrset: dict[str, Any]) -> None:
         self.rrsets = [
             record_set
             for record_set in self.rrsets
@@ -395,7 +424,7 @@ class FakeZone(CloudFormationModel):
 
     def add_vpc(
         self, vpc_id: Optional[str], vpc_region: Optional[str]
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         vpc = {}
         if vpc_id is not None:
             vpc["vpc_id"] = vpc_id
@@ -408,7 +437,7 @@ class FakeZone(CloudFormationModel):
     def delete_vpc(self, vpc_id: str) -> None:
         self.vpcs = [vpc for vpc in self.vpcs if vpc["vpc_id"] != vpc_id]
 
-    def get_record_sets(self, start_type: str, start_name: str) -> List[RecordSet]:
+    def get_record_sets(self, start_type: str, start_name: str) -> list[RecordSet]:
         def predicate(rrset: RecordSet) -> bool:
             rrset_name_reversed = reverse_domain_name(rrset.name)
             start_name_reversed = reverse_domain_name(start_name)
@@ -449,20 +478,21 @@ class FakeZone(CloudFormationModel):
         region_name: str,
         **kwargs: Any,
     ) -> "FakeZone":
-        hosted_zone = route53_backends[account_id]["global"].create_hosted_zone(
-            resource_name, private_zone=False
-        )
+        hosted_zone = route53_backends[account_id][
+            get_partition(region_name)
+        ].create_hosted_zone(resource_name, private_zone=False)
         return hosted_zone
 
 
 class RecordSetGroup(CloudFormationModel):
-    def __init__(self, hosted_zone_id: str, record_sets: List[str]):
+    def __init__(self, region_name: str, hosted_zone_id: str, record_sets: list[str]):
+        self.region_name = region_name
         self.hosted_zone_id = hosted_zone_id
         self.record_sets = record_sets
 
     @property
     def physical_resource_id(self) -> str:
-        return f"arn:aws:route53:::hostedzone/{self.hosted_zone_id}"
+        return f"arn:{get_partition(self.region_name)}:route53:::hostedzone/{self.hosted_zone_id}"
 
     @staticmethod
     def cloudformation_name_type() -> str:
@@ -485,7 +515,7 @@ class RecordSetGroup(CloudFormationModel):
         properties = cloudformation_json["Properties"]
 
         zone_name = properties.get("HostedZoneName")
-        backend = route53_backends[account_id]["global"]
+        backend = route53_backends[account_id][get_partition(region_name)]
         hosted_zone = backend.get_hosted_zone_by_name(zone_name) if zone_name else None
         if hosted_zone is None:
             hosted_zone = backend.get_hosted_zone(properties["HostedZoneId"])
@@ -493,11 +523,10 @@ class RecordSetGroup(CloudFormationModel):
         for record_set in record_sets:
             hosted_zone.add_rrset(record_set)
 
-        return RecordSetGroup(hosted_zone.id, record_sets)
+        return RecordSetGroup(region_name, hosted_zone.id, record_sets)
 
 
 class QueryLoggingConfig(BaseModel):
-
     """QueryLoggingConfig class; this object isn't part of Cloudformation."""
 
     def __init__(
@@ -527,11 +556,11 @@ class QueryLoggingConfig(BaseModel):
 class Route53Backend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.zones: Dict[str, FakeZone] = {}
-        self.health_checks: Dict[str, HealthCheck] = {}
-        self.resource_tags: Dict[str, Any] = defaultdict(dict)
-        self.query_logging_configs: Dict[str, QueryLoggingConfig] = {}
-        self.delegation_sets: Dict[str, DelegationSet] = dict()
+        self.zones: dict[str, FakeZone] = {}
+        self.health_checks: dict[str, HealthCheck] = {}
+        self.resource_tags: dict[str, Any] = defaultdict(dict)
+        self.query_logging_configs: dict[str, QueryLoggingConfig] = {}
+        self.delegation_sets: dict[str, DelegationSet] = {}
 
     def _has_prev_conflicting_domain(
         self, name: str, delegation_set_id: Optional[str]
@@ -563,7 +592,9 @@ class Route53Backend(BaseBackend):
     ) -> FakeZone:
         if self._has_prev_conflicting_domain(name, delegation_set_id):
             raise ConflictingDomainExists(name, delegation_set_id)
-        new_id = create_route53_zone_id()
+        new_id = HostedZoneIdentifier(
+            self.account_id, name, delegation_set_id
+        ).generate(existing_ids=list(self.zones.keys()))
         caller_reference = caller_reference or create_route53_caller_reference()
         delegation_set = self.create_reusable_delegation_set(
             caller_reference=f"DelSet_{name}", delegation_set_id=delegation_set_id
@@ -625,7 +656,12 @@ class Route53Backend(BaseBackend):
         zone.delete_vpc(vpcid)
         return zone
 
-    def change_tags_for_resource(self, resource_id: str, tags: Any) -> None:
+    def change_tags_for_resource(
+        self, resource_type: str, resource_id: str, tags: Any
+    ) -> None:
+        if resource_type == "hostedzone" and resource_id not in self.zones:
+            raise NoSuchHostedZone(host_zone_id=resource_id)
+
         if "Tag" in tags:
             if isinstance(tags["Tag"], list):
                 for tag in tags["Tag"]:
@@ -641,17 +677,27 @@ class Route53Backend(BaseBackend):
                 else:
                     del self.resource_tags[resource_id][tags["Key"]]
 
-    def list_tags_for_resource(self, resource_id: str) -> Dict[str, str]:
+    def list_tags_for_resource(self, resource_id: str) -> dict[str, str]:
         if resource_id in self.resource_tags:
             return self.resource_tags[resource_id]
         return {}
 
+    def list_tags_for_resources(self, resource_ids: list[str]) -> list[dict[str, Any]]:
+        resources = []
+        for id in resource_ids:
+            resource_set = {"ResourceId": id, "Tags": {}}
+            resource_set["Tags"] = self.list_tags_for_resource(id)
+            resources.append(resource_set)
+        return resources
+
     def list_resource_record_sets(
         self, zone_id: str, start_type: str, start_name: str, max_items: int
-    ) -> Tuple[List[RecordSet], Optional[str], Optional[str], bool]:
+    ) -> tuple[list[RecordSet], Optional[str], Optional[str], bool]:
         """
         The StartRecordIdentifier-parameter is not yet implemented
         """
+        if start_name:
+            validate_domain_name(start_name)
         the_zone = self.get_hosted_zone(zone_id)
         all_records = list(the_zone.get_record_sets(start_type, start_name))
         records = all_records[0:max_items]
@@ -662,15 +708,23 @@ class Route53Backend(BaseBackend):
         return records, next_start_name, next_start_type, is_truncated
 
     def change_resource_record_sets(
-        self, zoneid: str, change_list: List[Dict[str, Any]]
+        self, zoneid: str, change_list: list[dict[str, Any]]
     ) -> None:
         the_zone = self.get_hosted_zone(zoneid)
 
         for value in change_list:
+            validate_domain_name(
+                value["ResourceRecordSet"]["Name"], code="InvalidChangeBatch"
+            )
             if value["Action"] == "CREATE" and value in the_zone.rr_changes:
                 name = value["ResourceRecordSet"]["Name"] + "."
                 _type = value["ResourceRecordSet"]["Type"]
-                raise ResourceRecordAlreadyExists(name=name, _type=_type)
+                # check if the record exists or just in rr_changes (journal)
+                all_records = list(
+                    the_zone.get_record_sets(start_type=_type, start_name=name)
+                )
+                if all_records:
+                    raise ResourceRecordAlreadyExists(name=name, _type=_type)
 
         for value in change_list:
             if value["Action"] == "DELETE":
@@ -722,17 +776,21 @@ class Route53Backend(BaseBackend):
                     the_zone.delete_rrset(record_set)
             the_zone.rr_changes.append(original_change)
 
-    def list_hosted_zones(self) -> List[FakeZone]:
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_hosted_zones(self) -> list[FakeZone]:
+        """
+        The parameters DelegationSetId and HostedZoneType are not yet implemented
+        """
         return list(self.zones.values())
 
     def list_hosted_zones_by_name(
-        self, dnsnames: Optional[List[str]]
-    ) -> Tuple[Optional[str], List[FakeZone]]:
+        self, dnsnames: Optional[list[str]]
+    ) -> tuple[Optional[str], list[FakeZone]]:
         if dnsnames:
             dnsname = dnsnames[0]
             if dnsname[-1] != ".":
                 dnsname += "."
-            zones = [zone for zone in self.list_hosted_zones() if zone.name == dnsname]
+            zones = [zone for zone in self.zones.values() if zone.name == dnsname]
         else:
             dnsname = None
             # sort by names, but with domain components reversed
@@ -744,16 +802,15 @@ class Route53Backend(BaseBackend):
                     domains = domains[-1:] + domains[:-1]
                 return ".".join(reversed(domains))
 
-            zones = self.list_hosted_zones()
-            zones = sorted(zones, key=sort_key)
+            zones = sorted(self.zones.values(), key=sort_key)
         return dnsname, zones
 
-    def list_hosted_zones_by_vpc(self, vpc_id: str) -> List[Dict[str, Any]]:
+    def list_hosted_zones_by_vpc(self, vpc_id: str) -> list[dict[str, Any]]:
         """
         Pagination is not yet implemented
         """
         zone_list = []
-        for zone in self.list_hosted_zones():
+        for zone in self.zones.values():
             if zone.private_zone is True:
                 this_zone = self.get_hosted_zone(zone.id)
                 for vpc in this_zone.vpcs:
@@ -775,10 +832,10 @@ class Route53Backend(BaseBackend):
         return the_zone
 
     def get_hosted_zone_count(self) -> int:
-        return len(self.list_hosted_zones())
+        return len(self.zones.values())
 
     def get_hosted_zone_by_name(self, name: str) -> Optional[FakeZone]:
-        for zone in self.list_hosted_zones():
+        for zone in self.zones.values():
             if zone.name == name:
                 return zone
         return None
@@ -798,7 +855,7 @@ class Route53Backend(BaseBackend):
         return zone
 
     def create_health_check(
-        self, caller_reference: str, health_check_args: Dict[str, Any]
+        self, caller_reference: str, health_check_args: dict[str, Any]
     ) -> HealthCheck:
         health_check_id = str(random.uuid4())
         health_check = HealthCheck(health_check_id, caller_reference, health_check_args)
@@ -808,7 +865,7 @@ class Route53Backend(BaseBackend):
         return health_check
 
     def update_health_check(
-        self, health_check_id: str, health_check_args: Dict[str, Any]
+        self, health_check_id: str, health_check_args: dict[str, Any]
     ) -> HealthCheck:
         health_check = self.health_checks.get(health_check_id)
         if not health_check:
@@ -843,7 +900,7 @@ class Route53Backend(BaseBackend):
 
         return health_check
 
-    def list_health_checks(self) -> List[HealthCheck]:
+    def list_health_checks(self) -> list[HealthCheck]:
         return list(self.health_checks.values())
 
     def delete_health_check(self, health_check_id: str) -> None:
@@ -858,24 +915,12 @@ class Route53Backend(BaseBackend):
     def get_health_check_status(self) -> None:
         pass  # Logic implemented in responses.py
 
-    @staticmethod
-    def _validate_arn(region: str, arn: str) -> None:
-        match = re.match(rf"arn:aws:logs:{region}:\d{{12}}:log-group:.+", arn)
-        if not arn or not match:
-            raise InvalidCloudWatchArn()
-
-        # The CloudWatch Logs log group must be in the "us-east-1" region.
-        match = re.match(r"^(?:[^:]+:){3}(?P<region>[^:]+).*", arn)
-        if not match or match.group("region") != "us-east-1":
-            raise InvalidCloudWatchArn()
-
     def create_query_logging_config(
-        self, region: str, hosted_zone_id: str, log_group_arn: str
+        self, hosted_zone_id: str, log_group_arn: str
     ) -> QueryLoggingConfig:
         """Process the create_query_logging_config request."""
         # Does the hosted_zone_id exist?
-        response = self.list_hosted_zones()
-        zones = list(response) if response else []
+        zones = list(self.zones.values())
         for zone in zones:
             if zone.id == hosted_zone_id:
                 break
@@ -883,7 +928,8 @@ class Route53Backend(BaseBackend):
             raise NoSuchHostedZone(hosted_zone_id)
 
         # Ensure CloudWatch Logs log ARN is valid, otherwise raise an error.
-        self._validate_arn(region, log_group_arn)
+        if not log_group_arn or not re.match(LOGS_GROUP_ARN_REGEX, log_group_arn):
+            raise InvalidCloudWatchArn()
 
         # Note:  boto3 checks the resource policy permissions before checking
         # whether the log group exists.  moto doesn't have a way of checking
@@ -893,12 +939,13 @@ class Route53Backend(BaseBackend):
         # logging doesn't grant Route 53 sufficient permission to create
         # a log stream in the specified log group."
 
-        from moto.logs import logs_backends  # pylint: disable=import-outside-toplevel
+        from moto.logs import logs_backends
 
-        response = logs_backends[self.account_id][region].describe_log_groups()
-        log_groups = response[0] if response else []
-        for entry in log_groups:  # type: ignore
-            if log_group_arn == entry["arn"]:
+        log_groups = logs_backends[self.account_id][
+            LOGS_GROUP_REGION
+        ].describe_log_groups()
+        for entry in log_groups[0] if log_groups else []:
+            if log_group_arn == f"{entry.arn}:*":
                 break
         else:
             # There is no CloudWatch Logs log group with the specified ARN.
@@ -932,15 +979,14 @@ class Route53Backend(BaseBackend):
             raise NoSuchQueryLoggingConfig()
         return self.query_logging_configs[query_logging_config_id]
 
-    @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_query_logging_configs(
         self, hosted_zone_id: Optional[str] = None
-    ) -> List[QueryLoggingConfig]:
+    ) -> list[QueryLoggingConfig]:
         """Return a list of query logging configs."""
         if hosted_zone_id:
             # Does the hosted_zone_id exist?
-            response = self.list_hosted_zones()
-            zones = list(response) if response else []
+            zones = list(self.zones.values())
             for zone in zones:
                 if zone.id == hosted_zone_id:
                     break
@@ -955,7 +1001,7 @@ class Route53Backend(BaseBackend):
         delegation_set_id: Optional[str] = None,
         hosted_zone_id: Optional[str] = None,
     ) -> DelegationSet:
-        name_servers: Optional[List[str]] = None
+        name_servers: Optional[list[str]] = None
         if hosted_zone_id:
             hosted_zone = self.get_hosted_zone(hosted_zone_id)
             name_servers = hosted_zone.delegation_set.name_servers  # type: ignore
@@ -965,7 +1011,7 @@ class Route53Backend(BaseBackend):
         self.delegation_sets[delegation_set.id] = delegation_set
         return delegation_set
 
-    def list_reusable_delegation_sets(self) -> List[DelegationSet]:
+    def list_reusable_delegation_sets(self) -> list[DelegationSet]:
         """
         Pagination is not yet implemented
         """
@@ -981,5 +1027,8 @@ class Route53Backend(BaseBackend):
 
 
 route53_backends = BackendDict(
-    Route53Backend, "route53", use_boto3_regions=False, additional_regions=["global"]
+    Route53Backend,
+    "route53",
+    use_boto3_regions=False,
+    additional_regions=PARTITION_NAMES,
 )
