@@ -7,7 +7,7 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_config, mock_iam, mock_lambda
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from .test_config_rules import TEST_REGION, managed_config_rule
@@ -49,19 +49,17 @@ def lambda_handler(event, context):
         return zip_output.read()
 
 
-@mock_lambda
 def create_lambda_for_config_rule():
     """Return the ARN of a lambda that can be used by a custom rule."""
     role_name = "test-role"
     lambda_role = None
-    with mock_iam():
-        iam_client = boto3.client("iam", region_name=TEST_REGION)
-        try:
-            lambda_role = iam_client.get_role(RoleName=role_name)["Role"]["Arn"]
-        except ClientError:
-            lambda_role = iam_client.create_role(
-                RoleName=role_name, AssumeRolePolicyDocument="test policy", Path="/"
-            )["Role"]["Arn"]
+    iam_client = boto3.client("iam", region_name=TEST_REGION)
+    try:
+        lambda_role = iam_client.get_role(RoleName=role_name)["Role"]["Arn"]
+    except ClientError:
+        lambda_role = iam_client.create_role(
+            RoleName=role_name, AssumeRolePolicyDocument="test policy", Path="/"
+        )["Role"]["Arn"]
 
     # Create the lambda function and identify its location.
     lambda_client = boto3.client("lambda", region_name=TEST_REGION)
@@ -78,7 +76,7 @@ def create_lambda_for_config_rule():
     )
 
 
-@mock_config
+@mock_aws
 def test_config_rules_source_details_errors():
     """Test error conditions with ConfigRule.Source_Details instantiation."""
     client = boto3.client("config", region_name=TEST_REGION)
@@ -145,9 +143,9 @@ def test_config_rules_source_details_errors():
     )
 
     custom_rule = custom_config_rule()
-    custom_rule["Source"]["SourceDetails"][0][
-        "MessageType"
-    ] = "ConfigurationItemChangeNotification"
+    custom_rule["Source"]["SourceDetails"][0]["MessageType"] = (
+        "ConfigurationItemChangeNotification"
+    )
     with pytest.raises(ClientError) as exc:
         client.put_config_rule(ConfigRule=custom_rule)
     err = exc.value.response["Error"]
@@ -159,7 +157,7 @@ def test_config_rules_source_details_errors():
     )
 
 
-@mock_config
+@mock_aws
 def test_valid_put_config_custom_rule():
     """Test valid put_config_rule API calls for custom rules."""
     client = boto3.client("config", region_name=TEST_REGION)
@@ -227,8 +225,8 @@ def test_valid_put_config_custom_rule():
     assert updated_rule["MaximumExecutionFrequency"] == "Six_Hours"
 
 
-@mock_config
-def test_config_rules_source_errors():  # pylint: disable=too-many-statements
+@mock_aws
+def test_config_rules_source_errors():
     """Test various error conditions in ConfigRule.Source instantiation."""
     client = boto3.client("config", region_name=TEST_REGION)
 
@@ -290,7 +288,7 @@ def test_config_rules_source_errors():  # pylint: disable=too-many-statements
     err = exc.value.response["Error"]
     assert err["Code"] == "InsufficientPermissionsException"
     assert (
-        f'The AWS Lambda function {custom_rule["Source"]["SourceIdentifier"]} '
+        f"The AWS Lambda function {custom_rule['Source']['SourceIdentifier']} "
         f"cannot be invoked. Check the specified function ARN, and check the "
         f"function's permissions" in err["Message"]
     )
