@@ -2,11 +2,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2
+from moto import mock_aws
 from tests import EXAMPLE_AMI_ID
 
 
-@mock_ec2
+@mock_aws
 def test_console_output():
     conn = boto3.resource("ec2", "us-east-1")
     instances = conn.create_instances(ImageId=EXAMPLE_AMI_ID, MinCount=1, MaxCount=1)
@@ -15,7 +15,7 @@ def test_console_output():
     assert output.get("Output") is not None
 
 
-@mock_ec2
+@mock_aws
 def test_console_output_without_instance():
     client = boto3.client("ec2", "us-east-1")
 
